cache.h: define constants LOCK_SUFFIX and LOCK_SUFFIX_LEN
authorMichael Haggerty <mhagger@alum.mit.edu>
Wed, 1 Oct 2014 10:28:15 +0000 (12:28 +0200)
committerJunio C Hamano <gitster@pobox.com>
Wed, 1 Oct 2014 20:45:11 +0000 (13:45 -0700)
There are a few places that use these values, so define constants for
them.

Signed-off-by: Michael Haggerty <mhagger@alum.mit.edu>
Signed-off-by: Junio C Hamano <gitster@pobox.com>
cache.h
lockfile.c
refs.c
diff --git a/refs.c b/refs.c
index 0e324770c9b06730d49cf60436d431c4a2a3f6ec..73d6baedb09568c7938d6842fd4ed3f9a589ffbd 100644 (file)
--- a/refs.c
+++ b/refs.c
@@ -79,7 +79,8 @@ static int check_refname_component(const char *refname, int flags)
                if (refname[1] == '\0')
                        return -1; /* Component equals ".". */
        }
-       if (cp - refname >= 5 && !memcmp(cp - 5, ".lock", 5))
+       if (cp - refname >= LOCK_SUFFIX_LEN &&
+           !memcmp(cp - LOCK_SUFFIX_LEN, LOCK_SUFFIX, LOCK_SUFFIX_LEN))
                return -1; /* Refname ends with ".lock". */
        return cp - refname;
 }
@@ -2602,11 +2603,11 @@ static int delete_ref_loose(struct ref_lock *lock, int flag)
 {
        if (!(flag & REF_ISPACKED) || flag & REF_ISSYMREF) {
                /* loose */
-               int err, i = strlen(lock->lk->filename) - 5; /* .lock */
+               int err, i = strlen(lock->lk->filename) - LOCK_SUFFIX_LEN;
 
                lock->lk->filename[i] = 0;
                err = unlink_or_warn(lock->lk->filename);
-               lock->lk->filename[i] = '.';
+               lock->lk->filename[i] = LOCK_SUFFIX[0];
                if (err && errno != ENOENT)
                        return 1;
        }
diff --git a/cache.h b/cache.h
index 0a76d023e4cd5a835a6c8c41002c575c53c276fd..24891a81d6be0b41dd0a9526fe786d2b2a80c7d1 100644 (file)
--- a/cache.h
+++ b/cache.h
@@ -570,6 +570,10 @@ extern void fill_stat_cache_info(struct cache_entry *ce, struct stat *st);
 #define REFRESH_IN_PORCELAIN   0x0020  /* user friendly output, not "needs update" */
 extern int refresh_index(struct index_state *, unsigned int flags, const struct pathspec *pathspec, char *seen, const char *header_msg);
 
+/* String appended to a filename to derive the lockfile name: */
+#define LOCK_SUFFIX ".lock"
+#define LOCK_SUFFIX_LEN 5
+
 struct lock_file {
        struct lock_file *next;
        int fd;
index 2680dc949d60a99f571fcdcec293229ffd205f02..23847fc9f2d0f678a34b343902d304a8d022840a 100644 (file)
@@ -166,10 +166,11 @@ static char *resolve_symlink(char *p, size_t s)
 static int lock_file(struct lock_file *lk, const char *path, int flags)
 {
        /*
* subtract 5 from size to make sure there's room for adding
* ".lock" for the lock file name
         */
-       static const size_t max_path_len = sizeof(lk->filename) - 5;
+       static const size_t max_path_len = sizeof(lk->filename) -
+                                          LOCK_SUFFIX_LEN;
 
        if (!lock_file_list) {
                /* One-time initialization */
@@ -194,7 +195,7 @@ static int lock_file(struct lock_file *lk, const char *path, int flags)
        strcpy(lk->filename, path);
        if (!(flags & LOCK_NODEREF))
                resolve_symlink(lk->filename, max_path_len);
-       strcat(lk->filename, ".lock");
+       strcat(lk->filename, LOCK_SUFFIX);
        lk->fd = open(lk->filename, O_RDWR | O_CREAT | O_EXCL, 0666);
        if (0 <= lk->fd) {
                lk->owner = getpid();
@@ -308,7 +309,7 @@ int commit_lock_file(struct lock_file *lk)
        if (close_lock_file(lk))
                return -1;
        strcpy(result_file, lk->filename);
-       i = strlen(result_file) - 5; /* .lock */
+       i = strlen(result_file) - LOCK_SUFFIX_LEN; /* .lock */
        result_file[i] = 0;
        if (rename(lk->filename, result_file))
                return -1;
@@ -166,10 +166,11 @@ static char *resolve_symlink(char *p, size_t s)
 {
        /*
-        * subtract 5 from size to make sure there's room for adding
-        * ".lock" for the lock file name
+        * subtract LOCK_SUFFIX_LEN from size to make sure there's
+        * room for adding ".lock" for the lock file name:
         */